@@ -1,14 +1,29 @@
 /*
-   Copyright 2007 - 2008 MySQL AB, 2008 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+
+
 #ifndef _MYSQL_ART_RESULTSET_H_
 #define _MYSQL_ART_RESULTSET_H_
 
@@ -109,7 +124,7 @@ public:
 	typedef std::vector< MyVal > row_t;
 	typedef std::list< row_t > rset_t;
 
-	MySQL_ArtResultSet(const StringList& fn, rset_t * const rset, boost::shared_ptr< MySQL_DebugLogger > & l);
+	MySQL_ArtResultSet(const StringList& fn, boost::shared_ptr< rset_t > &rset, boost::shared_ptr< MySQL_DebugLogger > & l);
 	virtual ~MySQL_ArtResultSet();
 
 	bool absolute(int row);
@@ -233,7 +248,7 @@ protected:
 public:
 
 	unsigned int num_fields;
-	boost::scoped_ptr< MySQL_ArtResultSet::rset_t > rset;
+	boost::shared_ptr< MySQL_ArtResultSet::rset_t > rset;
 	rset_t::iterator current_record;
 	bool started;
 
