@@ -47,7 +47,7 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 
 #include "mysql_debug.h"
 
-//Prevent windows min() macro
+//Prevent windows min() macro because of std::numeric_limits<int>::min()
 #undef min
 
 namespace sql
@@ -91,7 +91,7 @@ MySQL_Prepared_ResultSet::MySQL_Prepared_ResultSet(
             MySQL_Prepared_Statement * par,
             boost::shared_ptr< MySQL_DebugLogger > & l
         )
-    : row(NULL), proxy(s), last_queried_column(-1), row_position(0), parent(par),
+    : row(NULL), proxy(s), last_queried_column(std::numeric_limits<uint32_t>::max()), row_position(0), parent(par),
      is_valid(true), logger(l), result_bind(r_bind), resultset_type(rset_type)
 {
     CPP_ENTER("MySQL_Prepared_ResultSet::MySQL_Prepared_ResultSet");
@@ -215,7 +215,9 @@ MySQL_Prepared_ResultSet::checkScrollable() const
         throw sql::NonScrollableException("Nonscrollable result set");
     }
     // reset last_queried_column
-    last_queried_column = -1;
+    last_queried_column = std::numeric_limits<uint32_t>::max();
+
+
 }
 /* }}} */
 
@@ -444,6 +446,7 @@ MySQL_Prepared_ResultSet::getDouble(const uint32_t columnIndex) const
         case sql::DataType::LONGVARBINARY:
         case sql::DataType::SET:
         case sql::DataType::ENUM:
+        case sql::DataType::JSON:
         {
             CPP_INFO("It's a string");
             long double ret = sql::mysql::util::strtold(getString(columnIndex).c_str(), NULL);
@@ -612,6 +615,7 @@ MySQL_Prepared_ResultSet::getInt64_intern(const uint32_t columnIndex, bool /* cu
         case sql::DataType::LONGVARBINARY:
         case sql::DataType::SET:
         case sql::DataType::ENUM:
+        case sql::DataType::JSON:
             CPP_INFO("It's a string");
             return strtoll(getString(columnIndex).c_str(), NULL, 10);
         case sql::DataType::BIT:
@@ -759,6 +763,7 @@ MySQL_Prepared_ResultSet::getUInt64_intern(const uint32_t columnIndex, bool /* c
         case sql::DataType::LONGVARBINARY:
         case sql::DataType::SET:
         case sql::DataType::ENUM:
+        case sql::DataType::JSON:
             CPP_INFO("It's a string");
             return strtoull(getString(columnIndex).c_str(), NULL, 10);
         case sql::DataType::BIT:
@@ -1033,6 +1038,7 @@ MySQL_Prepared_ResultSet::getString(const uint32_t columnIndex) const
         case sql::DataType::LONGVARBINARY:
         case sql::DataType::SET:
         case sql::DataType::ENUM:
+        case sql::DataType::JSON:
             CPP_INFO("It's a string");
             return  sql::SQLString(static_cast<char *>(result_bind->rbind[columnIndex - 1].buffer), *result_bind->rbind[columnIndex - 1].length);
         default:
@@ -1264,7 +1270,7 @@ MySQL_Prepared_ResultSet::next()
         CPP_INFO_FMT("new_row_position=%llu ret=%d", row_position, ret);
     } else {
         // reset last_queried_column
-        last_queried_column = -1;
+        last_queried_column = std::numeric_limits<uint32_t>::max();
         int result = proxy->fetch();
         if (!result || result == MYSQL_DATA_TRUNCATED) {
             ret = true;
@@ -1339,7 +1345,7 @@ MySQL_Prepared_ResultSet::relative(const int rows)
             row_position = rows > 0? num_rows + 1 : 0; /* after last or before first */
         } else {
             row_position += rows;
-            proxy->data_seek(row_position - 1);
+            seek();
         }
     }
 
@@ -1417,7 +1423,7 @@ MySQL_Prepared_ResultSet::wasNull() const
     if (isBeforeFirstOrAfterLast()) {
         throw sql::InvalidArgumentException("MySQL_Prepared_ResultSet::wasNull: can't fetch because not on result set");
     }
-    if (last_queried_column == -1) {
+    if (last_queried_column == std::numeric_limits<uint32_t>::max()) {
         throw sql::InvalidArgumentException("MySQL_Prepared_ResultSet::wasNull: should be called only after one of the getter methods");
     }
     return *result_bind->rbind[last_queried_column - 1].is_null != 0;
