@@ -44,7 +44,7 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 
 #include "mysql_debug.h"
 
-//Prevent windows min() macro
+//Prevent windows min() macro because of std::numeric_limits<int>::min()
 #undef min
 
 namespace sql
@@ -926,7 +926,7 @@ MySQL_ResultSet::next()
             sql::SQLException e(proxy_p->error(), proxy_p->sqlstate(), proxy_p->errNo());
             throw e;
         }
-        if (ret = (row != NULL)) {
+        if ((ret = (row != NULL))) {
             ++row_position;
         } else {
             row_position = 0;
@@ -1062,7 +1062,7 @@ MySQL_ResultSet::wasNull() const
     if (isBeforeFirstOrAfterLast()) {
         throw sql::InvalidArgumentException("MySQL_ResultSet::wasNull: can't fetch because not on result set");
     }
-    if (last_queried_column == -1) {
+    if (last_queried_column == std::numeric_limits<uint32_t>::max()) {
         throw sql::InvalidArgumentException("MySQL_ResultSet::wasNull: should be called only after one of the getter methods");
     }
     return was_null;
