@@ -1,15 +1,30 @@
 /*
-   Copyright 2007 - 2008 MySQL AB, 2008 - 2009 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 
+
+
 /* *
 * Example of sql::ResultSetMetaData - meta data of a result set
 *
@@ -21,6 +36,8 @@
 #include <sstream>
 #include <stdexcept>
 
+#include <boost/scoped_ptr.hpp>
+
 /*
   Public interface of the MySQL Connector/C++.
   You might not use it but directly include directly the different
@@ -31,7 +48,7 @@
 /* Connection parameter and sample data */
 #include "examples.h"
 
-static void printResultSetMetaData(std::auto_ptr< sql::ResultSet > &res, std::auto_ptr< sql::ResultSet > &ps_res);
+static void printResultSetMetaData(boost::scoped_ptr< sql::ResultSet > &res, boost::scoped_ptr< sql::ResultSet > &ps_res);
 
 using namespace std;
 
@@ -55,12 +72,12 @@ int main(int argc, const char **argv)
 
 	try {
 		/* Using the Driver to create a conection */
-		std::auto_ptr< sql::Connection > con(sql::mysql::get_driver_instance()->connect(url, user, pass));
+		boost::scoped_ptr< sql::Connection > con(sql::mysql::get_driver_instance()->connect(url, user, pass));
 
 		con->setSchema(database);
 
 		/* Create a test table demonstrating the use of sql::Statement.execute() */
-		std::auto_ptr< sql::Statement > stmt(con->createStatement());
+		boost::scoped_ptr< sql::Statement > stmt(con->createStatement());
 		stmt->execute("DROP TABLE IF EXISTS test");
 		stmt->execute("CREATE TABLE test(id INT NOT NULL AUTO_INCREMENT PRIMARY KEY, label CHAR(1))");
 		cout << "#\t Test table created" << endl;
@@ -77,25 +94,25 @@ int main(int argc, const char **argv)
 		cout << "#\t Test table populated" << endl;
 
 		{
-			std::auto_ptr< sql::ResultSet > res(stmt->executeQuery("SELECT id AS column_alias, label FROM test AS table_alias LIMIT 1"));
-			std::auto_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("SELECT id AS column_alias, label FROM test AS table_alias LIMIT 1"));
-			std::auto_ptr< sql::ResultSet > ps_res(prep_stmt->executeQuery());
+			boost::scoped_ptr< sql::ResultSet > res(stmt->executeQuery("SELECT id AS column_alias, label FROM test AS table_alias LIMIT 1"));
+			boost::scoped_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("SELECT id AS column_alias, label FROM test AS table_alias LIMIT 1"));
+			boost::scoped_ptr< sql::ResultSet > ps_res(prep_stmt->executeQuery());
 			cout << "#\t SELECT id AS column_alias, label FROM test AS table_alias LIMIT 1" << endl;
 			printResultSetMetaData(res, ps_res);
 		}
 
 		{
-			std::auto_ptr< sql::ResultSet > res(stmt->executeQuery("SELECT 1.01, 'Hello world!'"));
-			std::auto_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("SELECT 1.01, 'Hello world!'"));
-			std::auto_ptr< sql::ResultSet > ps_res(prep_stmt->executeQuery());
+			boost::scoped_ptr< sql::ResultSet > res(stmt->executeQuery("SELECT 1.01, 'Hello world!'"));
+			boost::scoped_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("SELECT 1.01, 'Hello world!'"));
+			boost::scoped_ptr< sql::ResultSet > ps_res(prep_stmt->executeQuery());
 			cout << "#\t SELECT 1.01, 'Hello world!'" << endl;
 			printResultSetMetaData(res, ps_res);
 		}
 
 		{
-			std::auto_ptr< sql::ResultSet > res(stmt->executeQuery("DESCRIBE test"));
-			std::auto_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("DESCRIBE test"));
-			std::auto_ptr< sql::ResultSet > ps_res(prep_stmt->executeQuery());
+			boost::scoped_ptr< sql::ResultSet > res(stmt->executeQuery("DESCRIBE test"));
+			boost::scoped_ptr< sql::PreparedStatement > prep_stmt(con->prepareStatement("DESCRIBE test"));
+			boost::scoped_ptr< sql::ResultSet > ps_res(prep_stmt->executeQuery());
 			cout << "# \tDESCRIBE test" << endl;
 			printResultSetMetaData(res, ps_res);
 		}
@@ -114,7 +131,7 @@ int main(int argc, const char **argv)
 		- sql::SQLException (derived from std::runtime_error)
 		*/
 		cout << "# ERR: SQLException in " << __FILE__;
-		cout << "(" << __FUNCTION__ << ") on line " << __LINE__ << endl;
+		cout << "(" << EXAMPLE_FUNCTION << ") on line " << __LINE__ << endl;
 		/* Use what(), getErrorCode() and getSQLState() */
 		cout << "# ERR: " << e.what();
 		cout << " (MySQL error code: " << e.getErrorCode();
@@ -124,7 +141,7 @@ int main(int argc, const char **argv)
 
 	} catch (std::runtime_error &e) {
 		cout << "# ERR: runtime_error in " << __FILE__;
-		cout << "(" << __FUNCTION__ << ") on line " << __LINE__ << endl;
+		cout << "(" << EXAMPLE_FUNCTION << ") on line " << __LINE__ << endl;
 		cout << "# ERR: " << e.what() << endl;
 
 		ret = EXIT_FAILURE;
@@ -141,7 +158,7 @@ int main(int argc, const char **argv)
 * Prints all meta data associated with an result set
 *
 */
-static void printResultSetMetaData(std::auto_ptr< sql::ResultSet > &res, std::auto_ptr< sql::ResultSet > &ps_res)
+static void printResultSetMetaData(boost::scoped_ptr< sql::ResultSet > &res, boost::scoped_ptr< sql::ResultSet > &ps_res)
 {
 	/* ResultSetMetaData object */
 	sql::ResultSetMetaData * meta;
