@@ -1,14 +1,29 @@
 /*
-   Copyright 2007 - 2008 MySQL AB, 2008 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+
+
 /* *
 * Basic example demonstrating how to check the type of a result set column
 *
@@ -20,6 +35,8 @@
 #include <sstream>
 #include <stdexcept>
 
+#include <boost/scoped_ptr.hpp>
+
 /* Public interface of the MySQL Connector/C++ */
 #include <driver/mysql_public_iface.h>
 /* Connection parameter and sample data */
@@ -57,10 +74,10 @@ int main(int argc, const char **argv)
 	try {
 		/* Using the Driver to create a connection */
 		driver = sql::mysql::get_driver_instance();
-		std::auto_ptr< sql::Connection > con(driver->connect(url, user, pass));
+		boost::scoped_ptr< sql::Connection > con(driver->connect(url, user, pass));
 		con->setSchema(database);
 
-		std::auto_ptr< sql::Statement > stmt(con->createStatement());
+		boost::scoped_ptr< sql::Statement > stmt(con->createStatement());
 		stmt->execute("DROP TABLE IF EXISTS test");
 
 		/*
@@ -74,7 +91,7 @@ int main(int argc, const char **argv)
 			"c_long BIGINT, c_double DOUBLE, c_null INT DEFAULT NULL)");
 		cout << "#\t Test table created" << endl;
 
-		std::auto_ptr< sql::PreparedStatement> prep_stmt(
+		boost::scoped_ptr< sql::PreparedStatement> prep_stmt(
 			con->prepareStatement("INSERT INTO test(id, label, c_bool, c_long, "
 				" c_double) VALUES (?, ?, ?, ?, ?)"));
 
@@ -98,7 +115,7 @@ int main(int argc, const char **argv)
 		}
 		cout << "#\t Test table populated" << endl;
 
-		std::auto_ptr< sql::ResultSet > res(stmt->executeQuery("SELECT id, label, c_bool, c_long, c_double, c_null FROM test ORDER BY id ASC"));
+		boost::scoped_ptr< sql::ResultSet > res(stmt->executeQuery("SELECT id, label, c_bool, c_long, c_double, c_null FROM test ORDER BY id ASC"));
 		while (res->next()) {
 			/* sql::ResultSet.rowsCount() returns size_t */
 			size_t row = res->getRow() - 1;
@@ -194,7 +211,7 @@ int main(int argc, const char **argv)
 		- sql::SQLException (derived from std::runtime_error)
 		*/
 		cout << "# ERR: SQLException in " << __FILE__;
-		cout << "(" << __FUNCTION__ << ") on line " << __LINE__ << endl;
+		cout << "(" << EXAMPLE_FUNCTION << ") on line " << __LINE__ << endl;
 		/* Use what(), getErrorCode() and getSQLState() */
 		cout << "# ERR: " << e.what();
 		cout << " (MySQL error code: " << e.getErrorCode();
@@ -205,7 +222,7 @@ int main(int argc, const char **argv)
 	} catch (std::runtime_error &e) {
 
 		cout << "# ERR: runtime_error in " << __FILE__;
-		cout << "(" << __FUNCTION__ << ") on line " << __LINE__ << endl;
+		cout << "(" << EXAMPLE_FUNCTION << ") on line " << __LINE__ << endl;
 		cout << "# ERR: " << e.what() << endl;
 		cout << "not ok 1 - examples/resultset_types.cpp" << endl;
 
