@@ -1,14 +1,29 @@
 /*
-   Copyright 2007 - 2008 MySQL AB, 2008 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+
+
 /**
 * Basic example of creating a stand alone program linked against Connector/C++
 *
@@ -26,7 +41,11 @@
 *
 * To run the example on Linux try something similar to:
 *
-*  LD_LIBRARY_PATH=/usr/local/lib/ ./standalone localhost root root
+*  LD_LIBRARY_PATH=/usr/local/lib/ ./standalone
+*
+* or:
+*
+*  LD_LIBRARY_PATH=/usr/local/lib/ ./standalone host user password database
 *
 */
 
@@ -37,6 +56,8 @@
 #include <sstream>
 #include <stdexcept>
 
+#include <boost/scoped_ptr.hpp>
+
 
 /*
   Include directly the different
@@ -75,11 +96,11 @@ int main(int argc, const char **argv)
 	try {
 		sql::Driver * driver = sql::mysql::get_driver_instance();
 		/* Using the Driver to create a connection */
-		std::auto_ptr< sql::Connection > con(driver->connect(url, user, pass));
+		boost::scoped_ptr< sql::Connection > con(driver->connect(url, user, pass));
 		con->setSchema(database);
 
-		std::auto_ptr< sql::Statement > stmt(con->createStatement());
-		std::auto_ptr< sql::ResultSet > res(stmt->executeQuery("SELECT 'Welcome to Connector/C++' AS _message"));
+		boost::scoped_ptr< sql::Statement > stmt(con->createStatement());
+		boost::scoped_ptr< sql::ResultSet > res(stmt->executeQuery("SELECT 'Welcome to Connector/C++' AS _message"));
 		cout << "\t... running 'SELECT 'Welcome to Connector/C++' AS _message'" << endl;
 		while (res->next()) {
 			cout << "\t... MySQL replies: " << res->getString("_message") << endl;
@@ -96,7 +117,7 @@ int main(int argc, const char **argv)
 		- sql::SQLException (derived from std::runtime_error)
 		*/
 		cout << "# ERR: SQLException in " << __FILE__;
-		cout << "(" << __FUNCTION__ << ") on line " << __LINE__ << endl;
+		cout << "(" << EXAMPLE_FUNCTION << ") on line " << __LINE__ << endl;
 		/* Use what() (derived from std::runtime_error) to fetch the error message */
 		cout << "# ERR: " << e.what();
 		cout << " (MySQL error code: " << e.getErrorCode();
