@@ -1,19 +1,33 @@
 /*
-   Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
+
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
- */
 
 
 #include <time.h>
 #include "BlobTest.h"
 
-#include <boost/scoped_ptr.hpp>
 
 #define BYTE_MAX_VALUE 255
 #define BYTE_MIN_VALUE 0
@@ -33,24 +47,28 @@ const String BlobTest::TEST_BLOB_FILE_PREFIX("cmj-testblob");
  */
 void BlobTest::setUp()
 {
-  super::setUp();
+	static int counter= 0;
+	// Just to make 2nd run(setString) to use smaller file(and be faster)
+	++counter;
 
-  realFrameworkTiming=TestsListener::doTiming();
+	super::setUp();
 
-  testBlobFile.reset(new FileUtils::ccppFile(TEST_BLOB_FILE_PREFIX + ".dat"));
+	realFrameworkTiming=TestsListener::doTiming();
 
-  int requiredSize=32 * 1024 * 1024;
+	testBlobFile.reset(new FileUtils::ccppFile(TEST_BLOB_FILE_PREFIX + ".dat"));
 
-  if (!versionMeetsMinimum(4, 0))
-  {
-    requiredSize=8 * 1024 * 1024;
-  }
+	int requiredSize=16 * 1024 * 1024/counter - (counter - 1)*128;
 
-  Timer::startTimer("BlobTest::testByteStreamInsert", "Blob File Creation", __FILE__, __LINE__);
-  createBlobFile(requiredSize);
-  TestsListener::messagesLog() << "Blob File Creation" << Timer::translate2seconds(Timer::stopTimer("BlobTest::testByteStreamInsert", "Blob File Creation")) << std::endl;
+	if (!versionMeetsMinimum(4, 0))
+	{
+		requiredSize=8 * 1024 * 1024;
+	}
 
-  createTestTable();
+	Timer::startTimer("BlobTest::testByteStreamInsert", "Blob File Creation", __FILE__, __LINE__);
+	createBlobFile(requiredSize);
+	TestsListener::messagesLog() << "Blob File Creation" << Timer::translate2seconds(Timer::stopTimer("BlobTest::testByteStreamInsert", "Blob File Creation")) << std::endl;
+
+	createTestTable();
 }
 
 /**
@@ -73,28 +91,46 @@ void BlobTest::tearDown()
 }
 
 /* throws Exception */
-void BlobTest::testByteStreamInsert()
-{
-  //SKIP("too slow");
-  testByteStreamInsert(conn);
-}
+  void BlobTest::testBlobStreamInsert()
+  {
+    //SKIP("too slow");
+    testBlobInsert( conn );
+  }
 
-/**
- * Tests inserting blob data as a stream
- *
- * @throws Exception
- *             if an error occurs
- */
-void BlobTest::testByteStreamInsert(Connection & c)
-{
-  std::fstream & bIn=testBlobFile->getStream();
 
-  ASSERT(!bIn.fail());
+  void BlobTest::testBlobStringInsert()
+  {
+    //SKIP("too slow");
+    testBlobInsert( conn, true );
+  }
 
-  TIMER_START("Populating blob table");
-  pstmt.reset(conn->prepareStatement("INSERT INTO BLOBTEST(blobdata) VALUES (?)"));
-  pstmt->setBlob(1, & bIn);
-  pstmt->execute();
+  /**
+	 * Tests inserting blob data as a stream
+	 *
+	 * @throws Exception
+	 *             if an error occurs
+	 */
+  void BlobTest::testBlobInsert( Connection & c, bool asString )
+  {
+    TIMER_START( "Populating blob table" );
+    pstmt.reset( conn->prepareStatement("INSERT INTO BLOBTEST(blobdata) VALUES (?)") );
+
+    if ( asString )
+    {
+      sql::SQLString str;
+      testBlobFile->readFile( const_cast<std::string&>(str.asStdString()) );
+
+      pstmt->setString( 1, str );
+      pstmt->execute();
+    }
+    else
+    {
+      std::fstream & bIn= testBlobFile->getStream();
+      ASSERT( ! bIn.fail() );
+
+      pstmt->setBlob( 1, & bIn );
+      pstmt->execute();
+    }
   TIMER_STOP("Populating blob table");
   pstmt->clearParameters();
 
