@@ -28,7 +28,7 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 #include <limits>
 #include "driver/mysql_error.h"
 
-//Prevent windows min() macro
+//Prevent windows min() macro because of std::numeric_limits<int>::min()
 #undef min
 
 namespace testsuite
@@ -961,5 +961,76 @@ void bugs::bug21067193()
 
 }
 
+void bugs::bug21152054()
+{
+
+  stmt->execute("DROP TABLE IF EXISTS bug21152054");
+  stmt->execute("create table bug21152054(c1 int);" );
+  stmt->execute("insert into  bug21152054 values(1), (2), (3), (4);" );
+  pstmt.reset( con->prepareStatement("select c1 from bug21152054;") );
+  res.reset( pstmt->executeQuery() );
+  ASSERT_EQUALS(true, res->absolute(4));
+  ASSERT_EQUALS(4, res->getInt(1));
+  int line = 4;
+  ASSERT_EQUALS(true, res->relative(-1));
+  do
+  {
+    --line;
+    ASSERT_EQUALS(line, res->getInt(1));
+  }  while(res->relative(-1));
+
+
+}
+
+void bugs::bug22292073()
+{
+
+  stmt->execute("DROP TABLE IF EXISTS bug22292073");
+  stmt->execute("create table bug22292073 (jdoc JSON);" );
+  stmt->execute("insert into bug22292073 values('{ \"name\": \"abc\", \"age\": 1 , \"misc\":\
+                1.2}'), ('{ \"name\": \"abcdef\", \"age\": 31 , \"misc\": 1.237843}');" );
+  pstmt.reset( con->prepareStatement("select JSON_EXTRACT(jdoc, '$.age') from bug22292073;") );
+  res.reset( pstmt->executeQuery() );
+
+  res->next();
+
+  ASSERT_EQUALS(true, res->getBoolean(1));
+  ASSERT_EQUALS(1, res->getInt(1));
+  ASSERT_EQUALS((int64_t)1L, res->getInt64(1));
+  ASSERT_EQUALS(1, res->getUInt(1));
+  ASSERT_EQUALS(1UL, res->getUInt64(1));
+  ASSERT_EQUALS(1.0, res->getDouble(1));
+
+  res->next();
+
+  ASSERT_EQUALS(true, res->getBoolean(1));
+  ASSERT_EQUALS(31, res->getInt(1));
+  ASSERT_EQUALS((int64_t)31L, res->getInt64(1));
+  ASSERT_EQUALS(31, res->getUInt(1));
+  ASSERT_EQUALS(31UL, res->getUInt64(1));
+  ASSERT_EQUALS(31.0, res->getDouble(1));
+
+  stmt.reset(con->createStatement());
+  res.reset(stmt->executeQuery("select JSON_EXTRACT(jdoc, '$.age') from bug22292073;"));
+
+  res->next();
+
+  ASSERT_EQUALS(true, res->getBoolean(1));
+  ASSERT_EQUALS(1, res->getInt(1));
+  ASSERT_EQUALS((int64_t)1L, res->getInt64(1));
+  ASSERT_EQUALS(1, res->getUInt(1));
+  ASSERT_EQUALS(1UL, res->getUInt64(1));
+  ASSERT_EQUALS(1.0, res->getDouble(1));
+
+  res->next();
+
+  ASSERT_EQUALS(true, res->getBoolean(1));
+  ASSERT_EQUALS(31, res->getInt(1));
+  ASSERT_EQUALS((int64_t)31L, res->getInt64(1));
+  ASSERT_EQUALS(31, res->getUInt(1));
+  ASSERT_EQUALS(31UL, res->getUInt64(1));
+  ASSERT_EQUALS(31.0, res->getDouble(1));
+}
+
 } /* namespace regression */
 } /* namespace testsuite */
