@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
 
 The MySQL Connector/C++ is licensed under the terms of the GPLv2
 <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -506,6 +506,41 @@ void connectionmetadata::getColumns()
       FAIL("TODO - see --verbose warnings");
     }
 
+    try {
+      bool input_value=true;
+      bool output_value=false;
+      void * input;
+      void * output;
+
+      stmt->execute("CREATE TABLE test(id INT,val VARCHAR(20))");
+
+      input=(static_cast<bool *> (&input_value));
+      output=(static_cast<bool *> (&output_value));
+
+      con->setClientOption("metadataUseInfoSchema", input);
+      con->getClientOption("metadataUseInfoSchema", output);
+      ASSERT_EQUALS(input_value, output_value);
+
+      dbmeta=con->getMetaData();
+      res.reset(dbmeta->getColumns(con->getCatalog(), "", "test", "%"));
+      ASSERT(res->rowsCount() == 2);
+
+      input_value=false;
+      output_value=true;
+
+      con->setClientOption("metadataUseInfoSchema", input);
+      con->getClientOption("metadataUseInfoSchema", output);
+      ASSERT_EQUALS(input_value, output_value);
+
+      dbmeta=con->getMetaData();
+      res.reset(dbmeta->getColumns(con->getCatalog(), "", "test", "%"));
+      ASSERT(res->rowsCount() == 2);
+    }
+    catch (sql::SQLException &)
+    {
+      FAIL("getColumns() does not work properly for metadataUseInfoSchema");
+    }
+
     stmt->execute("DROP TABLE IF EXISTS test");
     res.reset(dbmeta->getColumns(con->getCatalog(), con->getSchema(), "test", "id"));
     ASSERT(!res->next());
@@ -522,19 +557,18 @@ void connectionmetadata::getColumns()
 void connectionmetadata::getConnection()
 {
   logMsg("connectionmetadata::getConnection() - MySQL_ConnectionMetaData::getConnection");
-  Connection same_con;
+  sql::Connection *same_con;
   try
   {
     stmt.reset(con->createStatement());
     stmt->execute("SET @this_is_my_connection_id=101");
     DatabaseMetaData * dbmeta=con->getMetaData();
-    same_con.reset(dbmeta->getConnection());
+    same_con= dbmeta->getConnection();
     stmt.reset(same_con->createStatement());
     res.reset(stmt->executeQuery("SELECT @this_is_my_connection_id AS _connection_id"));
     ASSERT(res->next());
     ASSERT_EQUALS(101, res->getInt("_connection_id"));
     ASSERT_EQUALS(res->getInt(1), res->getInt("_connection_id"));
-    same_con.release(); // if the same don't clean it, it will be double free
   }
   catch (sql::SQLException &e)
   {
@@ -2144,5 +2178,218 @@ void connectionmetadata::bestIdUniqueNotNull()
   ASSERT(!res->next());
 }
 
+
+void connectionmetadata::getSchemaCollation()
+{
+  logMsg("connectionmetadata::getSchemaCollation - MySQL_ConnectionMetaData::getSchemaCollation()");
+  try
+  {
+	ResultSetMetaData * resmeta;
+	DatabaseMetaData * dbmeta=con->getMetaData();
+
+	stmt.reset(con->createStatement());
+	stmt->execute("DROP DATABASE IF EXISTS collationTestDatabase");
+	stmt->execute("CREATE DATABASE collationTestDatabase CHARACTER SET utf8 COLLATE utf8_bin");
+
+	/* SchemaCollation */
+	res.reset(dbmeta->getSchemaCollation(con->getCatalog(), "collationTestDatabase"));
+	ASSERT(res->next());
+	resmeta=res->getMetaData();
+	ASSERT_EQUALS((unsigned int) 3, resmeta->getColumnCount());
+	ASSERT_EQUALS("SCHEMA_CAT", resmeta->getColumnLabel(1));
+	ASSERT_EQUALS("SCHEMA_NAME", resmeta->getColumnLabel(2));
+	ASSERT_EQUALS("SCHEMA_COLLATION", resmeta->getColumnLabel(3));
+
+	ASSERT(res->getString("SCHEMA_NAME").caseCompare("collationTestDatabase") == 0);
+	ASSERT_EQUALS("utf8_bin", res->getString("SCHEMA_COLLATION"));
+
+	stmt->execute("DROP DATABASE IF EXISTS collationTestDatabase");
+  }
+  catch (sql::SQLException &e)
+  {
+
+    logErr(e.what());
+    logErr("SQLState: " + std::string(e.getSQLState()));
+    fail(e.what(), __FILE__, __LINE__);
+  }
+}
+
+
+void connectionmetadata::getSchemaCharset()
+{
+  logMsg("connectionmetadata::getSchemaCharset - MySQL_ConnectionMetaData::getSchemaCharset()");
+  try
+  {
+	ResultSetMetaData * resmeta;
+	DatabaseMetaData * dbmeta=con->getMetaData();
+
+	stmt.reset(con->createStatement());
+	stmt->execute("DROP DATABASE IF EXISTS charsetTestDatabase");
+	stmt->execute("CREATE DATABASE charsetTestDatabase CHARACTER SET utf8 COLLATE utf8_bin");
+
+	/* SchemaCharset */
+	res.reset(dbmeta->getSchemaCharset(con->getCatalog(), "charsetTestDatabase"));
+	ASSERT(res->next());
+	resmeta=res->getMetaData();
+	ASSERT_EQUALS((unsigned int) 3, resmeta->getColumnCount());
+	ASSERT_EQUALS("SCHEMA_CAT", resmeta->getColumnLabel(1));
+	ASSERT_EQUALS("SCHEMA_NAME", resmeta->getColumnLabel(2));
+	ASSERT_EQUALS("SCHEMA_CHARSET", resmeta->getColumnLabel(3));
+
+	ASSERT(res->getString("SCHEMA_NAME").caseCompare("charsetTestDatabase") == 0);
+	ASSERT_EQUALS("utf8", res->getString("SCHEMA_CHARSET"));
+
+	stmt->execute("DROP DATABASE IF EXISTS charsetTestDatabase");
+  }
+  catch (sql::SQLException &e)
+  {
+
+    logErr(e.what());
+    logErr("SQLState: " + std::string(e.getSQLState()));
+    fail(e.what(), __FILE__, __LINE__);
+  }
+}
+
+
+void connectionmetadata::getTableCollation()
+{
+  logMsg("connectionmetadata::getTableCollation - MySQL_ConnectionMetaData::getTableCollation()");
+  try
+  {
+	ResultSetMetaData * resmeta;
+	DatabaseMetaData * dbmeta=con->getMetaData();
+
+	stmt.reset(con->createStatement());
+	stmt->execute("DROP DATABASE IF EXISTS collationTestDatabase");
+	stmt->execute("CREATE DATABASE collationTestDatabase CHARACTER SET utf8 COLLATE utf8_bin");
+	stmt->execute("DROP TABLE IF EXISTS collationTestDatabase.collationTestTable");
+	stmt->execute("CREATE TABLE collationTestDatabase.collationTestTable(id INT) CHARACTER SET latin1 COLLATE latin1_general_ci");
+	stmt->execute("DROP TABLE IF EXISTS collationTestDatabase.collationTestTableAnother");
+	stmt->execute("CREATE TABLE collationTestDatabase.collationTestTableAnother(id INT) CHARACTER SET utf8 COLLATE utf8_bin");
+
+	/* TableCollation */
+	res.reset(dbmeta->getTableCollation(con->getCatalog(), "collationTestDatabase", "%collationTestTable%"));
+	ASSERT(res->next());
+	resmeta=res->getMetaData();
+	ASSERT_EQUALS((unsigned int) 4, resmeta->getColumnCount());
+	ASSERT_EQUALS("TABLE_CAT", resmeta->getColumnLabel(1));
+	ASSERT_EQUALS("TABLE_SCHEMA", resmeta->getColumnLabel(2));
+	ASSERT_EQUALS("TABLE_NAME", resmeta->getColumnLabel(3));
+	ASSERT_EQUALS("TABLE_COLLATION", resmeta->getColumnLabel(4));
+
+	ASSERT(res->getString("TABLE_SCHEMA").caseCompare("collationTestDatabase") == 0);
+	ASSERT(res->getString("TABLE_NAME").caseCompare("collationTestTable") == 0);
+	ASSERT_EQUALS("latin1_general_ci", res->getString("TABLE_COLLATION"));
+
+	ASSERT(res->next());
+	ASSERT(res->getString("TABLE_SCHEMA").caseCompare("collationTestDatabase") == 0);
+	ASSERT(res->getString("TABLE_NAME").caseCompare("collationTestTableAnother") == 0);
+	ASSERT_EQUALS("utf8_bin", res->getString("TABLE_COLLATION"));
+
+	stmt->execute("DROP DATABASE IF EXISTS collationTestDatabase");
+  }
+  catch (sql::SQLException &e)
+  {
+
+    logErr(e.what());
+    logErr("SQLState: " + std::string(e.getSQLState()));
+    fail(e.what(), __FILE__, __LINE__);
+  }
+}
+
+
+void connectionmetadata::getTableCharset()
+{
+  logMsg("connectionmetadata::getTableCharset - MySQL_ConnectionMetaData::getTableCharset()");
+  try
+  {
+	ResultSetMetaData * resmeta;
+	DatabaseMetaData * dbmeta=con->getMetaData();
+
+	stmt.reset(con->createStatement());
+	stmt->execute("DROP DATABASE IF EXISTS charsetTestDatabase");
+	stmt->execute("CREATE DATABASE charsetTestDatabase CHARACTER SET utf8 COLLATE utf8_bin");
+	stmt->execute("DROP TABLE IF EXISTS charsetTestDatabase.charsetTestTable");
+	stmt->execute("CREATE TABLE charsetTestDatabase.charsetTestTable(id INT) CHARACTER SET latin1 COLLATE latin1_general_ci");
+	stmt->execute("DROP TABLE IF EXISTS charsetTestDatabase.charsetTestTableAnother");
+	stmt->execute("CREATE TABLE charsetTestDatabase.charsetTestTableAnother(id INT) CHARACTER SET utf8 COLLATE utf8_bin");
+
+	/* TableCharset */
+	res.reset(dbmeta->getTableCharset(con->getCatalog(), "charsetTestDatabase", "%charsetTestTable%"));
+	ASSERT(res->next());
+	resmeta=res->getMetaData();
+	ASSERT_EQUALS((unsigned int) 4, resmeta->getColumnCount());
+	ASSERT_EQUALS("TABLE_CAT", resmeta->getColumnLabel(1));
+	ASSERT_EQUALS("TABLE_SCHEMA", resmeta->getColumnLabel(2));
+	ASSERT_EQUALS("TABLE_NAME", resmeta->getColumnLabel(3));
+	ASSERT_EQUALS("TABLE_CHARSET", resmeta->getColumnLabel(4));
+
+	ASSERT(res->getString("TABLE_SCHEMA").caseCompare("charsetTestDatabase") == 0);
+	ASSERT(res->getString("TABLE_NAME").caseCompare("charsetTestTable") == 0);
+	ASSERT_EQUALS("latin1", res->getString("TABLE_CHARSET"));
+
+	ASSERT(res->next());
+	ASSERT(res->getString("TABLE_SCHEMA").caseCompare("charsetTestDatabase") == 0);
+	ASSERT(res->getString("TABLE_NAME").caseCompare("charsetTestTableAnother") == 0);
+	ASSERT_EQUALS("utf8", res->getString("TABLE_CHARSET"));
+
+	stmt->execute("DROP DATABASE IF EXISTS charsetTestDatabase");
+  }
+  catch (sql::SQLException &e)
+  {
+
+    logErr(e.what());
+    logErr("SQLState: " + std::string(e.getSQLState()));
+    fail(e.what(), __FILE__, __LINE__);
+  }
+}
+
+
+void connectionmetadata::getTables()
+{
+  logMsg("connectionmetadata::getTables - MySQL_ConnectionMetaData::getTables()");
+  try
+  {
+	ResultSetMetaData * resmeta;
+	DatabaseMetaData * dbmeta=con->getMetaData();
+	std::list< sql::SQLString > tableTypes;
+
+	stmt.reset(con->createStatement());
+	stmt->execute("DROP TABLE IF EXISTS testTable1");
+	stmt->execute("CREATE TABLE testTable1(id INT)");
+	stmt->execute("DROP VIEW IF EXISTS testView1");
+	stmt->execute("CREATE VIEW testView1 AS SELECT * FROM testTable1");
+
+	/* for tableType = TABLE */
+	tableTypes.clear();
+	tableTypes.push_back(sql::SQLString("TABLE"));
+	res.reset(dbmeta->getTables("", "%", "testTable%", tableTypes));
+	ASSERT(res->next());
+
+	ASSERT_EQUALS(res->getString(3), "testTable1");
+	ASSERT_EQUALS(res->getString(4), "TABLE");
+
+	/* for tableType = VIEW */
+	tableTypes.clear();
+	tableTypes.push_back(sql::SQLString("VIEW"));
+	res.reset(dbmeta->getTables("", "%", "testView%", tableTypes));
+	ASSERT(res->next());
+
+	ASSERT_EQUALS(res->getString(3), "testView1");
+	ASSERT_EQUALS(res->getString(4), "VIEW");
+
+  	stmt->execute("DROP TABLE IF EXISTS testTable1");
+	stmt->execute("DROP VIEW IF EXISTS testView1");
+  }
+  catch (sql::SQLException &e)
+  {
+
+    logErr(e.what());
+    logErr("SQLState: " + std::string(e.getSQLState()));
+    fail(e.what(), __FILE__, __LINE__);
+  }
+}
+
+
 } /* namespace connectionmetadata */
 } /* namespace testsuite */
