@@ -1,14 +1,28 @@
-
 /*
-   Copyright 2009 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
+
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
+
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
- */
 
 #include <cppconn/prepared_statement.h>
 #include <cppconn/connection.h>
@@ -968,7 +982,7 @@ bool preparedstatement::createSP(std::string sp_code)
 void preparedstatement::callSP()
 {
   logMsg("preparedstatement::callSP() - MySQL_PreparedStatement::*()");
-  std::string sp_code("CREATE PROCEDURE p(OUT ver_param VARCHAR(25)) BEGIN SELECT VERSION() INTO ver_param; END;");
+  std::string sp_code("CREATE PROCEDURE p(OUT ver_param VARCHAR(250)) BEGIN SELECT VERSION() INTO ver_param; END;");
   try
   {
     if (!createSP(sp_code))
@@ -1155,11 +1169,6 @@ void preparedstatement::callSPMultiRes()
 {
   logMsg("preparedstatement::callSPMultiRes() - MySQL_PreparedStatement::*()");
 
-  int mysql_version=getMySQLVersion(con);
-  if (mysql_version < 60008)
-    SKIP("http://bugs.mysql.com/bug.php?id=44521 - Server crash");
-
-
   try
   {
     std::string sp_code("CREATE PROCEDURE p() BEGIN SELECT 1; SELECT 2; SELECT 3; END;");
@@ -1278,10 +1287,15 @@ void preparedstatement::getWarnings()
     stmt->execute("DROP TABLE IF EXISTS test");
     stmt->execute("CREATE TABLE test(id INT UNSIGNED)");
 
+	// Generating 2  warnings to make sure we get only the last 1 - won't hurt
     // Lets hope that this will always cause a 1264 or similar warning
-    pstmt.reset(con->prepareStatement("INSERT INTO test(id) VALUES (-1)"));
+    pstmt.reset(con->prepareStatement("INSERT INTO test(id) VALUES (?)"));
+	pstmt->setInt(1, -2);
     pstmt->executeUpdate();
+	pstmt->setInt(1, -1);
+	pstmt->executeUpdate();
 
+	int count= 0;
     for (const sql::SQLWarning* warn=pstmt->getWarnings(); warn; warn=warn->getNextWarning())
     {
       msg.str("");
@@ -1300,8 +1314,12 @@ void preparedstatement::getWarnings()
         ASSERT(("" != warn->getSQLState()));
       }
       ASSERT(("" != warn->getMessage()));
+
+	  ++count;
     }
 
+	ASSERT_EQUALS(1, count);
+
     for (const sql::SQLWarning* warn=pstmt->getWarnings(); warn; warn=warn->getNextWarning())
     {
       msg.str("");
@@ -1328,6 +1346,15 @@ void preparedstatement::getWarnings()
       FAIL("There should be no more warnings!");
     }
 
+	pstmt->setInt(1, -3);
+	pstmt->executeUpdate();
+	ASSERT(pstmt->getWarnings() != NULL);
+	// Statement without tables access does not reset warnings.
+	pstmt.reset(con->prepareStatement("SELECT 1"));
+    res.reset(pstmt->executeQuery());
+	ASSERT(pstmt->getWarnings() == NULL);
+    ASSERT(res->next());
+
     // TODO - how to use getNextWarning() ?
     stmt->execute("DROP TABLE IF EXISTS test");
   }
@@ -1405,7 +1432,7 @@ void preparedstatement::blob()
     ASSERT_EQUALS(res->getString("col1"), blob_input_stream.str());
     ASSERT_EQUALS(res->getString("col1"), blob_input);
 
-    std::auto_ptr< std::istream > blob_output_stream(res->getBlob(2));
+    boost::scoped_ptr< std::istream > blob_output_stream(res->getBlob(2));
     blob_output_stream->seekg(std::ios::beg);
     blob_output_stream->get(blob_output, offset + 1);
     ASSERT_EQUALS(blob_input_stream.str(), blob_output);
@@ -1465,7 +1492,7 @@ void preparedstatement::executeQuery()
     int value=sql::ResultSet::TYPE_FORWARD_ONLY;
     con->setClientOption(option, static_cast<void *> (&value));
   }
-  catch (sql::MethodNotImplementedException &e)
+  catch (sql::MethodNotImplementedException &/*e*/)
   {
     /* not available */
     return;
