@@ -1,14 +1,28 @@
 /*
-   Copyright 2008 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
+
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
- */
 
 #include <cppconn/warning.h>
 
@@ -60,7 +74,7 @@ void resultsetmetadata::doGetCatalogName(bool is_ps, bool &got_warning)
 {
   std::stringstream msg;
   ResultSetMetaData * meta=res->getMetaData();
-  if (con->getCatalog() != meta->getCatalogName(1))
+  if (con->getCatalog() != "" && meta->getCatalogName(1) != "" && (con->getCatalog() != meta->getCatalogName(1)))
   {
     got_warning=true;
     msg.str("");
@@ -69,6 +83,14 @@ void resultsetmetadata::doGetCatalogName(bool is_ps, bool &got_warning)
     logMsg(msg.str());
   }
 
+  if (meta->getCatalogName(1) != "" && meta->getCatalogName(1) != "def") {
+    got_warning=true;
+    msg.str("");
+    msg << "...\t\tWARNING expecting catalog = 'def'";
+    msg << " got '" << meta->getCatalogName(1) << "'";
+    logMsg(msg.str());
+  }
+
   try
   {
     meta->getCatalogName(0);
@@ -214,13 +236,18 @@ void resultsetmetadata::getColumnNameAndLabel()
   {
     /* This is a dull test, its about code coverage not achieved with the JDBC tests */
     logMsg("... Statement");
-    runStandardQuery();
+    stmt.reset(con->createStatement());
+    stmt->execute("DROP TABLE IF EXISTS getColumnNameAndLabel");
+    stmt->execute("CREATE TABLE getColumnNameAndLabel(col1 INT, col2 VARCHAR(10))");
+    res.reset(stmt->executeQuery("SELECT col1 AS intColumn, col2 AS charColumn FROM getColumnNameAndLabel"));
     doGetColumnNameAndLabel(false);
 
     logMsg("... PreparedStatement");
-    runStandardPSQuery();
+    pstmt.reset(con->prepareStatement("SELECT col1 AS intColumn, col2 AS charColumn FROM getColumnNameAndLabel"));
+    res.reset(pstmt->executeQuery());
     doGetColumnNameAndLabel(true);
 
+    stmt->execute("DROP TABLE IF EXISTS getColumnNameAndLabel");
   }
   catch (sql::SQLException &e)
   {
@@ -233,17 +260,11 @@ void resultsetmetadata::getColumnNameAndLabel()
 void resultsetmetadata::doGetColumnNameAndLabel(bool is_ps)
 {
   ResultSetMetaData * meta=res->getMetaData();
-  ASSERT_EQUALS("a", meta->getColumnName(1));
-  ASSERT_EQUALS(meta->getColumnLabel(1), meta->getColumnName(1));
-  /* NOTE: " " -> "" */
-  ASSERT_EQUALS("", meta->getColumnName(2));
-  ASSERT_EQUALS(meta->getColumnLabel(2), meta->getColumnName(2));
-  ASSERT_EQUALS("world", meta->getColumnName(3));
-  ASSERT_EQUALS(meta->getColumnLabel(3), meta->getColumnName(3));
-  ASSERT_EQUALS("!", meta->getColumnName(4));
-  ASSERT_EQUALS(meta->getColumnLabel(4), meta->getColumnName(4));
-  ASSERT_EQUALS("z", meta->getColumnName(5));
-  ASSERT_EQUALS(meta->getColumnLabel(5), meta->getColumnName(5));
+  ASSERT_EQUALS("col1", meta->getColumnName(1));
+  ASSERT_EQUALS("intColumn", meta->getColumnLabel(1));
+
+  ASSERT_EQUALS("col2", meta->getColumnName(2));
+  ASSERT_EQUALS("charColumn", meta->getColumnLabel(2));
 
   try
   {
@@ -329,6 +350,7 @@ void resultsetmetadata::getColumnType()
         ResultSetMetaData * meta=res->getMetaData();
         logMsg(it->sqldef);
         ASSERT_EQUALS(it->ctype, meta->getColumnType(1));
+
         ASSERT_EQUALS(it->name, meta->getColumnTypeName(1));
 
         sql.str("");
@@ -1399,6 +1421,109 @@ void resultsetmetadata::doIsWritable(bool is_ps)
   }
 }
 
+
+void resultsetmetadata::getColumnCharset()
+{
+  logMsg("resultsetmetadata::getColumnCharset() - MySQL_ResultSetMetaData::getColumnCharset()");
+  try
+  {
+	stmt.reset(con->createStatement());
+	stmt->execute("DROP TABLE IF EXISTS columnCharset");
+	stmt->execute("CREATE TABLE columnCharset(col1 VARCHAR(10) CHARACTER SET latin1 COLLATE latin1_general_ci)");
+	stmt->execute("INSERT INTO columnCharset VALUES ('cal1val')");
+	stmt->execute("SET @@character_set_results=NULL");
+
+	/* This is a dull test, its about code coverage not achieved with the JDBC tests */
+	logMsg("... Statement");
+	res.reset(stmt->executeQuery("SELECT col1 from columnCharset"));
+	doGetColumnCharset(false);
+
+	logMsg("... PreparedStatement");
+	pstmt.reset(con->prepareStatement("SELECT col1 from columnCharset"));
+	res.reset(pstmt->executeQuery());
+	checkResultSetScrolling(res);
+	doGetColumnCharset(true);
+  }
+  catch (sql::SQLException &e)
+  {
+    logErr(e.what());
+    logErr("SQLState: " + std::string(e.getSQLState()));
+    fail(e.what(), __FILE__, __LINE__);
+  }
+}
+
+
+void resultsetmetadata::doGetColumnCharset(bool is_ps)
+{
+  ResultSetMetaData * meta=res->getMetaData();
+  ASSERT_EQUALS("latin1", meta->getColumnCharset(1));
+
+  if (!is_ps)
+  {
+    res->close();
+    try
+    {
+      meta->getCatalogName(1);
+      FAIL("Can fetch meta from invalid resultset");
+    }
+    catch (sql::SQLException &)
+    {
+    }
+  }
+}
+
+
+void resultsetmetadata::getColumnCollation()
+{
+  logMsg("resultsetmetadata::getColumnCollation() - MySQL_ResultSetMetaData::getColumnCollation()");
+  try
+  {
+	stmt.reset(con->createStatement());
+	stmt->execute("DROP TABLE IF EXISTS columnCollation");
+	stmt->execute("CREATE TABLE columnCollation(col1 VARCHAR(10) COLLATE latin1_general_ci)");
+	stmt->execute("INSERT INTO columnCollation VALUES ('cal1val')");
+	stmt->execute("SET @@character_set_results=NULL");
+
+	/* This is a dull test, its about code coverage not achieved with the JDBC tests */
+	logMsg("... Statement");
+	res.reset(stmt->executeQuery("SELECT col1 from columnCollation"));
+	doGetColumnCollation(false);
+
+	logMsg("... PreparedStatement");
+	pstmt.reset(con->prepareStatement("SELECT col1 from columnCollation"));
+	res.reset(pstmt->executeQuery());
+	checkResultSetScrolling(res);
+	doGetColumnCollation(true);
+  }
+  catch (sql::SQLException &e)
+  {
+    logErr(e.what());
+    logErr("SQLState: " + std::string(e.getSQLState()));
+    fail(e.what(), __FILE__, __LINE__);
+  }
+}
+
+
+void resultsetmetadata::doGetColumnCollation(bool is_ps)
+{
+  ResultSetMetaData * meta=res->getMetaData();
+  ASSERT_EQUALS("latin1_general_ci", meta->getColumnCollation(1));
+
+  if (!is_ps)
+  {
+    res->close();
+    try
+    {
+      meta->getColumnCollation(1);
+      FAIL("Can fetch meta from invalid resultset");
+    }
+    catch (sql::SQLException &)
+    {
+    }
+  }
+}
+
+
 void resultsetmetadata::runStandardQuery()
 {
   stmt.reset(con->createStatement());
