@@ -1,19 +1,35 @@
 /*
-   Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
+
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
+
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
- */
 
 #include <cppconn/prepared_statement.h>
 #include <cppconn/connection.h>
 #include <cppconn/warning.h>
 #include "statement.h"
 #include <stdlib.h>
+#include <time.h>
 
 namespace testsuite
 {
@@ -48,6 +64,7 @@ void statement::getWarnings()
 {
   logMsg("statement::getWarnings() - MySQL_Statement::get|clearWarnings()");
   std::stringstream msg;
+  unsigned int count= 0;
 
   stmt.reset(con->createStatement());
   try
@@ -55,11 +72,14 @@ void statement::getWarnings()
     stmt->execute("DROP TABLE IF EXISTS test");
     stmt->execute("CREATE TABLE test(id INT UNSIGNED)");
 
+    // Generating 2  warnings to make sure we get only the last 1 - won't hurt
+    stmt->execute("INSERT INTO test(id) VALUES (-2)");
     // Lets hope that this will always cause a 1264 or similar warning
     stmt->execute("INSERT INTO test(id) VALUES (-1)");
 
     for (const sql::SQLWarning* warn=stmt->getWarnings(); warn; warn=warn->getNextWarning())
     {
+      ++count;
       msg.str("");
       msg << "... ErrorCode = '" << warn->getErrorCode() << "', ";
       msg << "SQLState = '" << warn->getSQLState() << "', ";
@@ -78,6 +98,8 @@ void statement::getWarnings()
       ASSERT(("" != warn->getMessage()));
     }
 
+    ASSERT_EQUALS(1, count);
+
     for (const sql::SQLWarning* warn=stmt->getWarnings(); warn; warn=warn->getNextWarning())
     {
       msg.str("");
@@ -99,9 +121,21 @@ void statement::getWarnings()
     }
 
     stmt->clearWarnings();
-    for (const sql::SQLWarning* warn=stmt->getWarnings(); warn; warn=warn->getNextWarning()) {
+    for (const sql::SQLWarning* warn=stmt->getWarnings(); warn; warn=warn->getNextWarning())
+    {
       FAIL("There should be no more warnings!");
-  }
+    }
+
+    // New warning
+    stmt->execute("INSERT INTO test(id) VALUES (-3)");
+    // Verifying we have warnings now
+    ASSERT(stmt->getWarnings() != NULL);
+
+    // Statement without tables access does not reset warnings.
+    stmt->execute("SELECT 1");
+    ASSERT(stmt->getWarnings() == NULL);
+    res.reset(stmt->getResultSet());
+    res->next();
 
     // TODO - how to use getNextWarning() ?
     stmt->execute("DROP TABLE IF EXISTS test");
@@ -193,7 +227,7 @@ void statement::callSP()
     ASSERT(!stmt->execute("CREATE TABLE test(id INT)"));
     ASSERT(!stmt->execute("CREATE PROCEDURE p() BEGIN INSERT INTO test(id) VALUES (123), (456); END;"));
     ASSERT(!stmt->execute("CALL p()"));
-    ASSERT_EQUALS(2, (int)stmt->getUpdateCount());
+    ASSERT_EQUALS(2, (int) stmt->getUpdateCount());
     ASSERT(stmt->execute("SELECT id FROM test ORDER BY id ASC"));
     res.reset(stmt->getResultSet());
     ASSERT(res->next());
@@ -201,7 +235,7 @@ void statement::callSP()
     ASSERT(!stmt->execute("DROP TABLE IF EXISTS test"));
     stmt->execute("DROP PROCEDURE IF EXISTS p");
 
-    ASSERT(!stmt->execute("CREATE PROCEDURE p(OUT ver_param VARCHAR(25)) BEGIN SELECT VERSION() INTO ver_param; END;"));
+    ASSERT(!stmt->execute("CREATE PROCEDURE p(OUT ver_param VARCHAR(250)) BEGIN SELECT VERSION() INTO ver_param; END;"));
     ASSERT(!stmt->execute("CALL p(@version)"));
     ASSERT(stmt->execute("SELECT @version AS _version"));
     res.reset(stmt->getResultSet());
@@ -209,7 +243,7 @@ void statement::callSP()
     ASSERT_EQUALS(dbmeta->getDatabaseProductVersion(), res->getString("_version"));
 
     stmt->execute("DROP PROCEDURE IF EXISTS p");
-    ASSERT(!stmt->execute("CREATE PROCEDURE p(IN ver_in VARCHAR(25), OUT ver_out VARCHAR(25)) BEGIN SELECT ver_in INTO ver_out; END;"));
+    ASSERT(!stmt->execute("CREATE PROCEDURE p(IN ver_in VARCHAR(250), OUT ver_out VARCHAR(250)) BEGIN SELECT ver_in INTO ver_out; END;"));
     ASSERT(!stmt->execute("CALL p('myver', @version)"));
     ASSERT(stmt->execute("SELECT @version AS _version"));
     res.reset(stmt->getResultSet());
@@ -231,7 +265,8 @@ void statement::callSP()
       {
         msg << res->getInt("id") << res->getString(2);
       }
-    } while (stmt->getMoreResults());
+    }
+    while (stmt->getMoreResults());
     ASSERT_EQUALS("1a2b3c", msg.str());
 
     stmt->execute("DROP PROCEDURE IF EXISTS p");
@@ -245,7 +280,8 @@ void statement::callSP()
       {
         msg << res->getInt("id") << res->getString(2);
       }
-    } while (stmt->getMoreResults());
+    }
+    while (stmt->getMoreResults());
     ASSERT_EQUALS("1a2b3c3c2b1a", msg.str());
 
   }
@@ -304,7 +340,7 @@ void statement::unbufferedFetch()
     logMsg("... setting TYPE_FORWARD_ONLY through connection map");
     connection_properties.erase("defaultStatementResultType");
     {
-      connection_properties["defaultStatementResultType"]= sql::ResultSet::TYPE_FORWARD_ONLY;
+      connection_properties["defaultStatementResultType"]=sql::ResultSet::TYPE_FORWARD_ONLY;
 
       try
       {
@@ -321,7 +357,14 @@ void statement::unbufferedFetch()
       stmt->execute("DROP TABLE IF EXISTS test");
 
       stmt->execute("CREATE TABLE test(id INT)");
-      stmt->execute("INSERT INTO test(id) VALUES (1), (2), (3), (4), (5)");
+      stmt->execute("INSERT INTO test(id) VALUES (0), (2), (3), (4), (5)");
+      ASSERT_EQUALS(5, (int) stmt->getUpdateCount());
+      stmt->execute("UPDATE test SET id = 1 WHERE id = 0");
+      ASSERT_EQUALS(1, (int) stmt->getUpdateCount());
+      stmt->execute("DELETE FROM test WHERE id = 1");
+      ASSERT_EQUALS(1, (int) stmt->getUpdateCount());
+      stmt->execute("INSERT INTO test(id) VALUES (1)");
+      ASSERT_EQUALS(1, (int) stmt->getUpdateCount());
 
       logMsg("... simple forward reading");
       res.reset(stmt->executeQuery("SELECT id FROM test ORDER BY id ASC"));
@@ -412,7 +455,7 @@ void statement::unbufferedFetch()
     stmt.reset(con->createStatement());
     res.reset((stmt->setResultSetType(sql::ResultSet::TYPE_FORWARD_ONLY)->executeQuery("SELECT id FROM test ORDER BY id ASC")));
     logMsg("... simple forward reading");
-    
+
     id=0;
     while (res->next())
     {
@@ -441,7 +484,7 @@ void statement::unbufferedFetch()
       id--;
     }
 
-   stmt->execute("DROP TABLE IF EXISTS test");
+    stmt->execute("DROP TABLE IF EXISTS test");
 
   }
   catch (sql::SQLException &e)
@@ -455,10 +498,10 @@ void statement::unbufferedFetch()
 void statement::unbufferedOutOfSync()
 {
   logMsg("statement::unbufferedOutOfSync() - MySQL_Statement::*");
-  
+
   try
   {
-    stmt.reset(con->createStatement());        
+    stmt.reset(con->createStatement());
     res.reset((stmt->setResultSetType(sql::ResultSet::TYPE_FORWARD_ONLY)->executeQuery("SELECT 1")));
     ASSERT_EQUALS(stmt->getResultSetType(), sql::ResultSet::TYPE_FORWARD_ONLY);
 
@@ -523,5 +566,35 @@ void statement::checkUnbufferedScrolling()
   }
 }
 
+
+void statement::queryTimeout()
+{
+  logMsg("statement::queryTimeout() - MySQL_Statement::setQueryTimeout");
+  int serverVersion= getMySQLVersion(con);
+  int timeout= 2;
+  if ( serverVersion < 57004 )
+  {
+    SKIP("Server version >= 5.7.4 needed to run this test");
+  }
+
+  stmt.reset(con->createStatement());
+  try
+  {
+    stmt->setQueryTimeout(timeout);
+    ASSERT_EQUALS(timeout, stmt->getQueryTimeout());
+    time_t t1= time(NULL);
+    stmt->execute("select sleep(5)");
+    time_t t2= time(NULL);
+    ASSERT((t2 -t1) < 5);
+  }
+  catch (sql::SQLException &e)
+  {
+    logErr(e.what());
+    logErr("SQLState: " + std::string(e.getSQLState()));
+    fail(e.what(), __FILE__, __LINE__);
+  }
+}
+
+
 } /* namespace statement */
 } /* namespace testsuite */
